@@ -1,7 +1,5 @@
 
-#' mnis_additional
-#'
-#' A series of basic function for the API lookup.
+#' A series of basic function for the API lookup. Each function accepts a member's ID and returns information; if no ID is given basic information on all members of both houses is returned.
 #' @param ID The member ID value. If empty, function calls \code{\link{mnis_all_members}} and returns basic information on all members of both houses.
 #' @param ref_dods Request based on the DODS membership ID scheme. Defaults to FALSE, where it requests data based on the default membership ID scheme.
 #' @param tidy If TRUE, fixes the variable names in the tibble to remove non-alphanumeric characters and superfluous text, and convert to a consistent style. Defaults to TRUE.
@@ -764,11 +762,11 @@ mnis_interests <- function(ID = NULL, ref_dods = FALSE, tidy = TRUE, tidy_style=
 
         dl <- data.frame(ID = rep(names(got), sapply(got, length)), Obs = unlist(got))
 
-        x <- as.list(got$Members$Member)
+        x <- t(dl)
 
-        x <- unlist(x)
+        x <- as.data.frame(x)
 
-        x <- t(x)
+        x <- x[rownames(x) != "ID", ]
 
         x <- tibble::as_tibble(x)
 
